@@ -6,9 +6,9 @@ CLI_CONFIG = {
     "skip": {"nargs": "*"},
     "remote": {},
     "root": {},
-    "acct_file": {"source": "acct", "default": "taco"},
+    "acct_file": {"source": "acct"},
     "acct_key": {"source": "acct"},
-    "acct_profile": {"source": "acct"},
+    "acct_profile": {"source": "idem"},
 }
 CONFIG = {
     "ver": {
